@@ -3,6 +3,7 @@ package org.gcube.common.storagehubwrapper.server;
 import java.io.InputStream;
 import java.net.URL;
 import java.util.List;
+import java.util.Map;
 
 import org.apache.commons.lang.Validate;
 import org.gcube.common.authorization.library.provider.SecurityTokenProvider;
@@ -180,8 +181,6 @@ public class StorageHubClientService {
 	 * Gets the item.
 	 *
 	 * @param itemId the item id
-	 * @param withAccounting the with accounting
-	 * @param withMetadata the with metadata
 	 * @return the item
 	 * @throws Exception the exception
 	 */
@@ -207,6 +206,25 @@ public class StorageHubClientService {
 	}
 
 
+
+	/**
+	 * Gets the metadata.
+	 *
+	 * @param itemId the item id
+	 * @return the metadata
+	 * @throws Exception the exception
+	 */
+	public Map<String, Object> getMetadata(String itemId) throws Exception{
+		setContextProviders(scope, authorizationToken);
+		ItemContainer<Item> itemCont = shcClient.open(itemId).asItem();
+		Metadata metadata = shcClient.open(itemId).asItem().get().getMetadata();
+		if(metadata!=null)
+			return metadata.getMap();
+
+		return null;
+	}
+
+
 	/**
 	 * Gets the folder container.
 	 *
@@ -431,7 +449,7 @@ public class StorageHubClientService {
 		}else{
 			streamDesc = shcClient.open(itemId).asFile().download(nodeIdsToExclude);
 		}
-		return new StreamDescriptor(streamDesc.getStream(), streamDesc.getFileName());
+		return new StreamDescriptor(streamDesc.getStream(), streamDesc.getFileName(), streamDesc.getContentType());
 
 	}
 
@@ -448,7 +466,7 @@ public class StorageHubClientService {
 
 		setContextProviders(scope, authorizationToken);
 		StreamDescriptor streamDesc = shcClient.open(folderId).asFolder().download(nodeIdsToExclude);
-		return new StreamDescriptor(streamDesc.getStream(), streamDesc.getFileName());
+		return new StreamDescriptor(streamDesc.getStream(), streamDesc.getFileName(), streamDesc.getContentType());
 
 	}
 
@@ -660,6 +678,24 @@ public class StorageHubClientService {
 	}
 
 
+	/**
+	 * Gets the public link for file version.
+	 *
+	 * @param fileItemId the file item id
+	 * @return the public link for file version
+	 * @throws Exception the exception
+	 */
+	public URL getPublicLinkForFileVersion(String fileItemId, String version) throws Exception{
+
+		Validate.notNull(fileItemId, "Bad request of getPublicLinkForFile, the fileItemId is null");
+		Validate.notNull(version, "Bad request of getPublicLinkForFileVersion, the version is null");
+		Validate.notEmpty(version, "Bad request of getPublicLinkForFileVersion, the version is empty");
+		setContextProviders(scope, authorizationToken);
+		return shcClient.open(fileItemId).asFile().getPublicLink(version);
+
+	}
+
+
 	/**
 	 * Gets the list versions.
 	 *
